/* eslint-disable no-console */
import { writeFileSync } from "node:fs";
import { join } from "node:path/posix";
import { DEFAULT_CONFIG, DEFAULT_CONFIG_FILE, DEFAULT_CONFIG_FILE_RAW, getConfig, } from "@postgresql-typed/util";
import debug from "debug";
import { g, y } from "../util/chalk.js";
import { GLOBAL_DEBUG_GLOB, LOGGER } from "../util/constants.js";
import { getConsoleHeader } from "../util/functions/getters/getConsoleHeader.js";
export class ConfigHandler {
    constructor() {
        this.filepath = null;
        this.config = DEFAULT_CONFIG.cli;
        this.LOGGER = LOGGER?.extend("ConfigHandler");
    }
    async loadConfig() {
        this.LOGGER?.("Loading config file...");
        //TODO allow passing config file path
        const result = await getConfig();
        if (!result.filePath) {
            this.LOGGER?.("No config file found");
            return this;
        }
        this.LOGGER?.("Config file loaded");
        this.config = result.config.cli;
        if (this.config.types.debug) {
            debug.enable(GLOBAL_DEBUG_GLOB);
            this.LOGGER?.("Debug mode enabled at a later point, to enable it earlier, use the --debug flag");
        }
        return this;
    }
    async initConfig() {
        this.LOGGER?.("Initializing config file...");
        const result = await getConfig();
        if (result?.filePath) {
            this.LOGGER?.("Config file already exists");
            console.log(getConsoleHeader(y("A configuration file is already present, skipping initialization..."), `File location: ${result.filePath}`));
            return 0;
        }
        try {
            const location = join(process.cwd(), DEFAULT_CONFIG_FILE);
            this.LOGGER?.("Writing config file to", location);
            writeFileSync(location, DEFAULT_CONFIG_FILE_RAW);
            console.log(getConsoleHeader(g("Successfully created configuration file!"), `File location: ${location}`));
            return 0;
        }
        catch (error) {
            console.error(error);
            return 1;
        }
    }
    get connections() {
        const environmentVariable = Object.keys(process.env)
            .filter(key => {
            if (key === this.config.connectionStringEnvironmentVariable)
                return true;
            const regex = new RegExp(`^${this.config.connectionStringEnvironmentVariable}_\\d+$`);
            return regex.test(key);
        })
            .map(key => process.env[key])
            .filter((value) => typeof value === "string");
        if (environmentVariable.length > 0)
            return environmentVariable;
        if (Array.isArray(this.config.connections))
            return this.config.connections;
        return [this.config.connections];
    }
}
//# sourceMappingURL=ConfigHandler.js.map