import { FileContent } from "../classes/FileContent.js";
import { mapGetOrSet } from "../util/functions/mapGetOrSet.js";
import { resolveFilename } from "../util/functions/resolveFileName.js";
export class PrinterContext {
    constructor(config) {
        this.config = config;
        this._files = new Map();
        this._rawFiles = new Map();
    }
    _pushDeclaration(id, mode, declaration) {
        const file = resolveFilename(this.config, id), fileContent = mapGetOrSet(this._files, file, () => new FileContent(this.config, file));
        return fileContent.pushDeclaration(id, mode, declaration);
    }
    pushTypeDeclaration(id, declaration) {
        return this._pushDeclaration(id, "type", declaration);
    }
    pushReExport(id, from) {
        const file = resolveFilename(this.config, id), fileContent = mapGetOrSet(this._files, file, () => new FileContent(this.config, file));
        fileContent.pushReExport(id, from);
    }
    pushValueDeclaration(id, declaration) {
        return this._pushDeclaration(id, "value", declaration);
    }
    writeFile(filename, content) {
        if (this._rawFiles.has(filename))
            throw new Error(`Cannot write the same file multiple times: ${filename}`);
        this._rawFiles.set(filename, content);
    }
    getFiles() {
        return [
            ...[...this._files.values()].map(file => ({
                filename: file.file,
                content: file.getContent(),
            })),
            ...[...this._rawFiles].map(([filename, content]) => ({
                filename,
                content,
            })),
        ];
    }
}
//# sourceMappingURL=PrinterContext.js.map